(jobexecution)=

# Job execution and submission

Modules managing the execution and submission of jobs to computing clusters.
This is mostly used for small productions during the validation or verification phase.

(job-manager)=

```{eval-rst}
.. automodule:: job_execution.job_manager
   :members:
```

(htcondor-submission)=

```{eval-rst}
.. automodule:: job_execution.htcondor_script_generator
   :members:
```
